@@ -8,12 +8,6 @@
       INTEGER I
       INTEGER IMAGE(300)
 
-	  do i=1,level
-		CL(i) = 1.0*(i-1)/(level-1)
-		call UIFPAC(level-i,0,0,ir(i))
-		call UIFPAC(0,level-i,0,ig(i))
-		call UIFPAC(0,0,level-i,ib(i))
-	  end do
 	  do i=1,nx
 		do j=1,ny
 			r(i,j) = exp(-((i-nx/2. )**2.  + (j-ny/2.)**2. ) / 5000.)
@@ -39,27 +33,8 @@
       CALL GRSTRN(1)
       CALL GRSTRF
 
-      call UISCMP(ig(1),ig(level),ib(1),ib(level))
-
       call prcopn('DclPaintGrid3')
-
-      if(nu1 /= nv1 .or. nu2 /= nv2) then
-        call msgdmp('E', 'DclPaintGrid2', 
-     *       'Size of arrays are not consistent.')
-      end if
-
-      call sgqvpt(vxmin, vxmax, vymin, vymax)
-
-      call stfpr2(vxmin, vymin, rx, ry)
-      call stfwtr(rx, ry, wx, wy)
-      call swfint(wx, wy, ix1, iy1)
-
-      call stfpr2(vxmax, vymax, rx, ry)
-      call stfwtr(rx, ry, wx, wy)
-      call swfint(wx, wy, ix2, iy2)
-
-      call uipd3z(rc, gc, bc, nx, nx, ny, image, iwidth)
-
+      call uipda3(rc, gc, bc, nx, nx, ny)
       call prccls('DclPaintGrid3')
 
       CALL UXAXDV('T', .1, .5)
