@@ -486,9 +486,8 @@ contains
   end subroutine
 
   subroutine ZMGOPN
-    if(zmqfcm()) then
-      if(i_rgb /= ifz .or. iwidth /= iwz) then
 
+    if(zmqfcm()) then
         OtbRed=i_rgb / 16777216
         i_rgb = i_rgb - OtbRed * 16777216
         OtbGreen=i_rgb / 65536
@@ -496,19 +495,14 @@ contains
         OtbBlue=i_rgb/256
 
         OtbRes=ChangeDCLPen(iwidth,OtbRed,OtbGreen,OtbBlue)
-
-       ifz = i_rgb
+        ifz = i_rgb
         icz = -1
         iwz = iwidth
-      end if
     else
-      if(icolor /= icz .or. iwidth /= iwz) then
         OtbRes=ChangeDCLPen(iwidth,OtbZMCOLOR2(1,icolor+1),OtbZMCOLOR2(2,icolor+1),OtbZMCOLOR2(3,icolor+1))
-
         icz = icolor
         ifz = -1
         iwz = iwidth
-      end if
     end if
   end subroutine
 
