@@ -101,6 +101,9 @@ void zgupdate(void)
     update_rect.width = drawing_area->allocation.width;
     update_rect.height = drawing_area->allocation.height;
 
+    while (gtk_events_pending())
+        gtk_main_iteration();
+
     gtk_widget_draw(drawing_area, &update_rect);
 
 }
@@ -923,10 +926,12 @@ void zgsrot_(DCL_INT *iwtrot)
 
 
 // New function for Fullcolor
-void zgsfcm_(DCL_INT *lfc){
+void zgsfcm_(DCL_INT *lfc)
+{
   lfcmod = *lfc;
 }
-void zgslcl_(DCL_INT *icolor){
+void zgslcl_(DCL_INT *icolor)
+{
   GdkColor loccx;
   GdkColormap *cmap;
 
@@ -940,7 +945,8 @@ void zgslcl_(DCL_INT *icolor){
   gdk_gc_set_foreground(gc,&loccx);
 
 }
-void zgstcl_(DCL_INT *icolor){
+void zgstcl_(DCL_INT *icolor)
+{
   /*This Function is not used in uipk samples
      So, it is not tested.*/
   /* set tone color in 24 bit RGB */
@@ -962,7 +968,8 @@ void zgstcl_(DCL_INT *icolor){
     gdk_gc_set_foreground(gct,&loccx);
 
 }
-void zgiclr_(DCL_INT *image,DCL_INT *nlen){
+void zgiclr_(DCL_INT *image,DCL_INT *nlen)
+{
   GdkColor  loccx;
   GdkColormap *cmap;
   int i;
@@ -994,7 +1001,8 @@ void zgiclr_(DCL_INT *image,DCL_INT *nlen){
 
 
 
-void zgclini_(char clrmap[], DCL_INT *lfgbg){
+void zgclini_(char clrmap[], DCL_INT *lfgbg)
+{
 
   void cfnchr();
 
