@@ -389,12 +389,12 @@ void zxqfcc_(DCL_INT *lfcatr)
   *lfcatr = LFCATR;
 }
 
-void zxsfcm_(DCL_INT lfc)
+void zxsfcm_(DCL_INT *lfc)
 {
   /* set full color mode */
 
 
-  lfcmod = lfc;
+  lfcmod = *lfc;
 
 }
 
@@ -416,6 +416,7 @@ void zxscli_(DCL_INT *iclidx)
   /* set line color index */
 
     iclidz = *iclidx % MAXCLI;
+
 /*  if (iclidz == 0)
 	iclidz = 1; */
 }
@@ -449,8 +450,10 @@ void zxgopn_(void)
   gv.cap_style  = CapRound;
   gv.line_width = linewidth[iwdidz-1];
 
-  if (lfcmod == FALSE)
+  if (lfcmod == FALSE){
     XSetForeground (d, gc, px[iclidz]);
+  }
+ 
 
   XChangeGC (d, gc, GCLineWidth | GCCapStyle, &gv);
 
@@ -762,7 +765,8 @@ void zxsrot_(DCL_INT *iwtrot)
   iwtroz = *iwtrot;
 }
 
-void zxclini_(char clrmap[], DCL_INT *lfgbg){
+void zxclini_(char clrmap[], DCL_INT *lfgbg)
+{
 
 /* change/initialize colormap */
 
